@@ -146,4 +146,12 @@ impl<K: Send + Sync + Hash + Clone + Eq + 'static, V: Send + Clone + Sync + 'sta
     pub fn reset(&self, value: Arc<HashMap<K, V>>) {
         self.inner.store(value);
     }
+
+    pub fn len(&self) -> usize {
+        self.inner().len()
+    }
+
+    pub fn is_empty(&self) -> bool {
+        self.inner().is_empty()
+    }
 }
